# League Infrastructure Utilities


## Development

We're using `uv` for project management. 

* Create a virtenv: `uv venv` or `uv venv --link-mode symlink`
* build: `uv build`.venv
* publish to PyPi: uv publish --token $UV_PUBLISH_TOKEN